# XXX: this information should be stored in the FTI instead.

javascript = {
    'Dummy Portlet': 'widget_portlet_dummy_js',
    'Text Portlet': '',
    'Search Portlet': 'widget_portlet_search_js',
    'Internal Links Portlet': '',
    'Add Item Portlet': '',
    'Breadcrumbs Portlet': '',
    'Actions Portlet': '',
    'Content Portlet': '',
    'Language Portlet': '',
    'Image Portlet': '',
    'Rotating Image Portlet': 'widget_portlet_rotating_image_js',
    'Navigation Portlet': 'widget_portlet_navigation_js',
    'Document Portlet': '',
    'RSS Portlet': '',
}

return javascript
